@@ -1,6 +1,4 @@
-__title__ = 'qartez'
-__version__ = '0.5'
-__build__ = 0x000005
+__title__ = 'qartez.constants'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __all__ = ('REL_ALTERNATE_HREFLANG_SITEMAP_TEMPLATE',)
 
@@ -8,7 +6,7 @@ __all__ = ('REL_ALTERNATE_HREFLANG_SITEMAP_TEMPLATE',)
 REL_ALTERNATE_HREFLANG_SITEMAP_TEMPLATE = """
 <xhtml:link
     rel="alternate"
-    hreflang="%(lang)s"
-    href="%(href)s"
+    hreflang="{lang}"
+    href="{href}"
     />
 """
